/* eslint-disable quotes */
const fs = require('fs')

const axios = require('axios')

const env = require('dotenv').config({
	path: `${process.cwd()}/.env`,
})

const { OPENWEATHER_KEY,POSITIONSTACK_KEY} = env.parsed

class Busquedas {
	historial = []
	dbPath = `${process.cwd()}/src/clima-app/db/database.json`

	constructor() {
		this.leerDB()
	}

	get historialCapitalizado() {
		return this.historial.map((lugar) => {
			let palabras = lugar.split(' ')
			palabras = palabras.map((p) => p[0].toUpperCase() + p.substring(1))

			return palabras.join(' ')
		})
	}

	// get paramsMapbox() {
	//   return {
	//     access_token: MAPBOX_KEY,
	//     limit: 5,
	//     language: "es",
	//   };
	// }

	get paramsPositionStack(){
		return {
			limit: 5,
			language: 'es'
		}
	}

	get paramsWeather() {
		return {
			appid: OPENWEATHER_KEY,
			units: 'metric',
			lang: 'es',
		}
	}

	/* 

baseURL: `https://api.mapbox.com/geocoding/v5/mapbox.places/${lugar}.json`,
*/

	async ciudad(lugar = '') {
		try {
			// Petición http
			// const intance = axios.create({
			// 	baseURL: `https://api.mapbox.com/geocoding/v5/mapbox.places/${lugar}.json`,
			// 	params: this.paramsMapbox,
			// })

			const intance = axios.create({
				baseURL: `http://api.positionstack.com/v1/forward`,
				params: {
					access_key: POSITIONSTACK_KEY,
					query: lugar
				}
			})

			const resp = await intance.get()
			return resp.data.data.map((lugar) => ({
				id: lugar.label,
				nombre: lugar.name,
				lng: lugar.longitude,
				lat: lugar.latitude,
			}))
		} catch (error) {
			//console.log("Errors", error);
			return []
		}
	}

	async climaLugar(lat, lon) {
		try {
			const instance = axios.create({
				baseURL: 'https://api.openweathermap.org/data/2.5/weather',
				params: { ...this.paramsWeather, lat, lon },
			})

			const resp = await instance.get()
			const { weather, main } = resp.data

			return {
				desc: weather[0].description,
				min: main.temp_min,
				max: main.temp_max,
				temp: main.temp,
			}
		} catch (error) {
			console.log(error)
		}
	}

	agregarHistorial(lugar = '') {
		if (this.historial.includes(lugar.toLocaleLowerCase())) {
			return
		}
		this.historial = this.historial.splice(0, 5)

		this.historial.unshift(lugar.toLocaleLowerCase())

		// Grabar en DB
		this.guardarDB()
	}

	guardarDB() {
		const payload = {
			historial: this.historial,
		}

		fs.writeFileSync(this.dbPath, JSON.stringify(payload))
	}

	leerDB() {
		if (!fs.existsSync(this.dbPath)) return

		const info = fs.readFileSync(this.dbPath, { encoding: 'utf-8' })
		const data = JSON.parse(info)
		this.historial = data.historial
	}
}

module.exports = Busquedas
