/**
 * Codigo relativo a un servidor web con funcionalidad de
 * socket.io para gestionar websockets.
 *
 * Esta clase Server es encargada de setear todas las
 * dependencias y librerías necesarias.
 */

const express = require("express");
const cors = require("cors");
const path = require("path");

const { socketController } = require("../sockets/controller");

class Server {
  constructor() {
    this.port = process.env.PORT || 3000;

    this.app = express();
    this.server = require("http").createServer(this.app);
    this.io = require("socket.io")(this.server);

    this.paths = {};

    // Middlewares
    this.middlewares();

    // Rutas de mi aplicación
    // this.routes();

    // Sockets
    this.sockets();
  }

  middlewares() {
    // CORS
    this.app.use(cors());

    const publicPath = path.resolve(__dirname, "../public");
    // Directorio Público
    this.app.use(express.static(publicPath));
  }

  sockets() {
    console.log("El servidor recibe la instancia del controlador");
    this.io.on("connection", socketController);
  }

  listen() {
    this.server.listen(this.port, () => {
      console.log("Servidor corriendo en puerto", this.port);
    });
  }
}

module.exports = Server;
